@@ -1,7 +1,9 @@
+from typing import Optional
+
 from torch import nn
 import torch
 
-def weight_decay_parameters_group(net: nn.Module, weight_decay_val: float, skip_list=()):
+def weight_decay_parameters_group(net: nn.Module, weight_decay_val, skip_list=()):
     """
     exclude bias from weight decay
     """
@@ -9,7 +11,7 @@ def weight_decay_parameters_group(net: nn.Module, weight_decay_val: float, skip_
     for name, param in net.named_parameters():
         if not param.requires_grad: # frozen weights
             continue
-        if len(param.shape) == 1 or name.endswith(".bias") or name.endswith("bias") or name in skip_list:
+        if len(param.shape) == 1 or name.endswith("bias") or name in skip_list:
             no_decay.append(param)
         else:
             decay.append(param)
